# Yaclog: Yet Another Commandline Changelog Tool

[![Documentation Status](https://readthedocs.org/projects/yaclog/badge/?version=latest)](https://yaclog.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://github.com/drewcassidy/yaclog/actions/workflows/python-publish.yml/badge.svg)](https://github.com/drewcassidy/yaclog/actions/workflows/python-publish.yml)
[![PyPI version](https://badge.fury.io/py/yaclog.svg)](https://badge.fury.io/py/yaclog)

Yaclog is a python library and command line tool to make it easier to keep track of changes to your projects.
It includes commands for appending new changes to a markdown changelog file, as well as releasing new versions
for deployment via git tags.

```{toctree}
---
maxdepth: 2
caption: Contents
---

handbook/index
reference/index
```

```{toctree}
---
maxdepth: 1
---

Changelog <changelog>
License <license>
```

## Indices and tables

* {ref}`genindex`
* {ref}`modindex`
* {ref}`search`
